# set term pngcairo size 540,360
# set term pop

set style line 1 lt 1 dt 1 lw 1.5 lc black pt 4 ps 0.75
set style line 2 lt 2 dt 2 lw 1.5 lc black pt 6 ps 0.75
set style line 3 lt 3 dt 3 lw 1.5 lc black pt 8 ps 0.75
set style line 4 lt 4 lw 1.5 lc black pt 10 ps 0.75
set style line 5 lt 5 lw 1.5 lc black pt 12 ps 0.75
set style line 6 lt 6 lw 1.5 lc black pt 14 ps 0.75
set style line 7 lt 7 lw 1.5 lc black pt 7 ps 0.75
set style line 8 lt 8 lw 1.5 lc black pt 9 ps 0.75
set style line 9 lt 9 lw 1.5 lc black pt 11 ps 0.75
set style increment user

set term svg size 650,550 enhanced
# set grid
set style line 1 lt rgb "black" lw 1.5 pt 4
set xtics font "Helvetica, 12"
set ytics font "Helvetica, 12"
# set xlabel font "{/Times:Italic}, 20"
# set ylabel font "{/Times:Italic}, 20"
set xlabel font "Times, 20"
set ylabel font "Times, 20"
set key on inside top box spacing 1.25 font "Helvetica, 12"
# set grid linestyle 4
 
set format x "%.1f"
set xlabel "Num. nodes"
set xrange [0.5:2.5]
set format y "%.2f"
set yrange [0.0:1.5]
set ylabel ""

##################################################################################
# Convergence of the vertical downward deflection (absolute value of z displacement)
# at the mid-point of the free edge of the Scordelis roof
##################################################################################

set output "Convergence vertical downward deflection.svg"
set xrange [70:450]
set yrange [0.260:0.310]
set ytics 0.01
set ylabel "|z| (m)"
set title "Convergence of the vertical downward deflection"
set key right bottom

plot "./reference_results.txt" using 1:2 with linespoints lc rgb "#8b1a0e" title "Mohan", \
"./reference_results.txt" using 1:3 with linespoints lc rgb "#8b1a0e" title "Chen (1992)", \
"./reference_results.txt" using 1:4 with linespoints lc rgb "#8b1a0e" title "Carpenter et al. (1985)", \
"./reference_results.txt" using 1:5 with linespoints lc rgb "#8b1a0e" title "STRI3", \
0.3024 lt 2 lc rgb "black" title "Exact value in [4]", \
"./res.0.txt" using 1:3 with linespoints lc rgb "#5e9c36" title "DKT triangle", \
"./res.0.txt" using 5:7 with linespoints lc rgb "#5e9c36" title "Drilling rotation triangle", \
"./res.0.txt" using 13:15 with linespoints lc rgb "#5e9c36" title "Quadratic quadrilateral", \
"./res.0.txt" using 9:11 with linespoints lc rgb "#5e9c36" title "Quadratic triangle"

set output "Convergence Shell (top) stress Sx.svg"
set xrange [70:450]
set format y "%.1E"
set yrange [1.5e5:2e5]
set ylabel "{/Symbol \s}_x (Pa)"
set ytics 1e4
set title "Convergence of the shell (top) stress Sx"
set key right bottom
plot "./res.0.txt" using 1:4 with linespoints title "DKT triangle", \
"./res.0.txt" using 5:8 with linespoints title "Drilling rotation triangle", \
"./res.0.txt" using 13:16 with linespoints title "Linear Quadrilateral", \
"./res.0.txt" using 9:12 with linespoints title "Quadratic triangle"

set term pop





